@@ -19,12 +19,22 @@ else
   fi
 fi
 
-export PKG=libtool-stable
-export VER=1.4.3
-export REL=1
+tscriptname=`basename $0 .sh`
+export PKG=`echo $tscriptname | sed -e 's/\-[^\-]*\-[^\-]*$//'`
+export VER=`echo $tscriptname | sed -e "s/${PKG}-//" -e 's/\-[^\-]*$//'`
+export REL=`echo $tscriptname | sed -e "s/${PKG}-${VER}-//"`
 export FULLPKG=${PKG}-${VER}-${REL}
 
-export src_orig_pkg_name=libtool-${VER}.tar.gz
+# determine correct decompression option and tarball filename
+if [ -e libtool-${VER}.tar.gz ] ; then
+  export opt_decomp=z
+  export src_orig_pkg_ext=gz
+elif [ -e libtool-${VER}.tar.bz2 ] ; then
+  export opt_decomp=j
+  export src_orig_pkg_ext=bz2
+fi
+
+export src_orig_pkg_name=libtool-${VER}.tar.${src_orig_pkg_ext}
 export src_pkg_name=${FULLPKG}-src.tar.bz2
 export src_patch_name=${FULLPKG}.patch
 export bin_pkg_name=${FULLPKG}.tar.bz2
@@ -53,38 +63,44 @@ mkdirs() {
 
 prep() {
   (cd ${topdir} && \
-  tar xvzf ${src_orig_pkg} && \
+  tar xv${opt_decomp}f ${src_orig_pkg} && \
   cd ${topdir} && \
   patch -p0 < ${src_patch} && \
-  mkdirs )
-}
+  mkdirs
+)}
+
 conf() {
   (export PATH=${prefix}/bin:${path_old} && \
   cd ${objdir} && \
   ${srcdir}/configure --build=${host} --target=${target} \
   --srcdir=${srcdir} --prefix=${prefix} \
   --exec-prefix=${prefix} --sysconfdir=${sysconfdir} \
-  --libdir=${prefix}/lib --includedir=/nonexistent/include && \
-  export PATH=${path_old} )
-}
+  --libdir=${prefix}/lib \
+  --mandir=${prefix}/share/man --infodir=${prefix}/share/info && \
+  export PATH=${path_old}
+)}
+
 build() {
   (export PATH=${prefix}/bin:${path_old} && \
   cd ${objdir} && \
   make CFLAGS=-O2 && make info && \
-  export PATH=${path_old} )
-}
+  export PATH=${path_old}
+)}
+
 check() {
   (export PATH=${prefix}/bin:${path_old} && \
   cd ${objdir} && \
   make check | tee ${checkfile} 2>&1 && \
-  export PATH=${path_old} )
-}
+  export PATH=${path_old}
+)}
+
 clean() {
   (export PATH=${prefix}/bin:${path_old} && \
   cd ${objdir} && \
   make clean && \
-  export PATH=${path_old} )
-}
+  export PATH=${path_old}
+)}
+
 install() {
   (export PATH=${prefix}/bin:${path_old} && \
   cd ${objdir} && \
@@ -93,47 +109,53 @@ install() {
   exec_prefix=${instdir}${prefix} \
   bindir=${instdir}${prefix}/bin \
   libdir=${instdir}${prefix}/lib \
+  mandir=${instdir}${prefix}/share/man \
+  infodir=${instdir}${prefix}/share/info \
   sysconfdir=${instdir}${sysconfdir} \
   includedir=${instdir}${prefix}/include \
   tooldir=${instdir}${prefix} && \
-  if [ -f ${instdir}${prefix}/info/dir ] ; then \
-    rm ${instdir}${prefix}/info/dir ; \
+  if [ -f ${instdir}${prefix}/share/info/dir ] ; then \
+    rm ${instdir}${prefix}/share/info/dir ; \
   fi && \
-  if [ ! -d ${instdir}${docprefix}/doc/Cygwin ]; then \
-    mkdir -p ${instdir}${docprefix}/doc/Cygwin ; \
+  if [ ! -d ${instdir}${docprefix}/share/doc/Cygwin ]; then \
+    mkdir -p ${instdir}${docprefix}/share/doc/Cygwin ; \
   fi && \
-  if [ ! -d ${instdir}${docprefix}/doc/${PKG}-${VER} ]; then \
-    mkdir -p ${instdir}${docprefix}/doc/${PKG}-${VER} ; \
+  if [ ! -d ${instdir}${docprefix}/share/doc/${PKG}-${VER} ]; then \
+    mkdir -p ${instdir}${docprefix}/share/doc/${PKG}-${VER} ; \
   fi && \
   /usr/bin/install -m 644 ${srcdir}/CYGWIN-PATCHES/${PKG}.README \
-    ${instdir}${docprefix}/doc/Cygwin/${PKG}-${VER}.README && \
+    ${instdir}${docprefix}/share/doc/Cygwin/${PKG}-${VER}.README && \
   /usr/bin/install -m 644 ${srcdir}/README \
     ${srcdir}/AUTHORS ${srcdir}/COPYING ${srcdir}/NEWS ${srcdir}/TODO \
-	 ${srcdir}/THANKS ${instdir}${docprefix}/doc/${PKG}-${VER} && \
-  export PATH=${path_old} )
-}
+    ${srcdir}/THANKS ${instdir}${docprefix}/share/doc/${PKG}-${VER} && \
+  export PATH=${path_old}
+)}
+
 mkpatch() {
   (export PATH=${prefix}/bin:${path_old} && \
   cd ${srcdir} && \
-  tar xvzf ${src_orig_pkg} && \
+  tar xv${opt_decomp}f ${src_orig_pkg} && \
   mv libtool-${VER} ../libtool-${VER}-orig && \
   cd ${topdir} && \
   diff -urN -x '.build' -x '.inst' -x '.sinst' \
     libtool-${VER}-orig libtool-${VER} > \
     ${srcinstdir}/${src_patch_name} ; \
   rm -rf libtool-${VER}-orig && \
-  export PATH=${path_old} )
-}
+  export PATH=${path_old} 
+)}
+
 strip() {
   (cd ${instdir} && \
-  find . -name "*.dll" | xargs strip > /dev/null 2>&1 )
-}
+  find . -name "*.dll" | xargs strip > /dev/null 2>&1
+)}
+
 pkg() {
   (export PATH=${prefix}/bin:${path_old} && \
   cd ${instdir} && \
   tar cvjf ${bin_pkg} * && \
-  export PATH=${path_old} )
-}
+  export PATH=${path_old}
+)}
+
 spkg() {
   (mkpatch && \
   export PATH=${prefix}/bin:${path_old} && \
@@ -141,13 +163,15 @@ spkg() {
   cp $0 ${srcinstdir}/`basename $0` && \
   cd ${srcinstdir} && \
   tar cvjf ${src_pkg} * && \
-  export PATH=${path_old} )
-}
+  export PATH=${path_old}
+)}
+
 finish() {
   (export PATH=${prefix}/bin:${path_old} && \
   rm -rf ${srcdir}
-  export PATH=${path_old} )
-}
+  export PATH=${path_old}
+)}
+
 case $1 in
   prep)	prep ; STATUS=$? ;;
   conf)	conf ; STATUS=$? ;;
